#!/bin/sh
# This script acts as a helper to the fvwm-crystal menu-method
# for the creation and removal of icons.
#
# Author: Michael Stilkerich <ms@mike2k.de>
#
# Usage:
# Create a new icon, if neccessary:
# createicon.sh <commandname> <iconfile>
# 
# Remove all created icons
# createicon.sh --remove

# To assign an icon, we will
# (1) check if there is already an icon assigned
#     to commandname in /usr/share/fvwm-crystal
# (2) check for the supplied iconfile. If found, it
#     is installed to /var/lib/fvwm-crystal
# (3) try to find an icon with commandname in system directories

FC_ICONBASE="/usr/share/fvwm-crystal/fvwm/icons/Default"
DM_ICONBASE="/var/lib/fvwm-crystal/icons/Default"
SYSTEM_ICONDIRS="/usr/share/pixmaps /usr/share/icons"
SIZES="22x22 32x32 48x48"

createicon() {
	if [ ! -z "`find ${FC_ICONBASE}/22x22 ${DM_ICONBASE}/22x22 -name "$1.png"`" ]; then
		# fvwm-crystal icon exists, nothing to do (1)
		exit 0
	fi

	if [ -r "$2" ]; then
		# use file hint pointed to by menu entry (2)
		ICONSRCFILE="$2"
	else
		# try to find a suitable icon in the system directories
		ICONSRCFILE=`find $SYSTEM_ICONDIRS -type f -iname "$1.png"`
		if [ -z "$ICONSRCFILE" ]; then
			ICONSRCFILE=`find $SYSTEM_ICONDIRS -type f -iname "$1.xpm"`
		fi
		if [ -z "$ICONSRCFILE" ]; then
			# give up
			exit 1
		fi
	fi

	for i in $ICONSRCFILE; do
		# convert the first found file to png of required sizes
		for size in ${SIZES}; do
			mkdir -p "${DM_ICONBASE}/${size}/apps"
			convert -resize ${size} "$i" "${DM_ICONBASE}/${size}/apps/$1.png"
		done
		break
	done
}

removeicons() {
	for size in ${SIZES}; do
		if [ ! -d "${DM_ICONBASE}/${size}/apps/" ]; then
			continue
		fi
		# Since only the debian menu resides in /var/lib, we can
		# savely delete the whole tree
		rm -rf -- "${DM_ICONBASE}/${size}/debianmenu"
		rm -rf -- "${DM_ICONBASE}/${size}/apps"
	done
}

case "$1" in
	--remove)
	removeicons
	;;

	*)
	createicon "$1" "$2"
	;;
esac
